#!/bin/ksh
#> This script will upgrade ErcRANOS 6.0.14.0.10
#

########################################################
# set paths and files

RELEASE='6.0.14.0.10'
RP=`echo $RELEASE|sed 's/\.//g'`
MODULE='ErcRANOS'
SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
BACKUP_DIR=${SourceDir}/Backup
export SQLPATH=${FLEXPM_HOME}/config
export wm_product='PROSPECT'
export WM_PRODUCT='PROSPECT'

########################################################


# Check env settings
echo '+ Checking environment...'

if ! [[ -d ${NE_BASE} ]]
then
    echo 'Env variable NE_BASE must be set to appropriate dir before installation.';exit 1
fi

if ! [[ -d ${PROSPECT_HOME} ]]
then
    echo 'Env variable PROSPECT_HOME must be set to appropriate dir before installation.';exit 1
fi

if [[ -z ${DB_CONNECT} ]]
then
    echo 'Env variable DB_CONNECT must be set to appropriate value before installation.';exit 1
fi

echo '+ Installing Patch...'

echo '+ Backing up original files...'
cd $NE_BASE
for file in `gtar -tzf ${SourceDir}/${MODULE}-${RP}.tgz`
do
    if [ -f $file ]
    then
        if [ ! -d ${BACKUP_DIR}/`dirname $file` ]
        then
            mkdir -p ${BACKUP_DIR}/`dirname $file`
        fi

        cp $file ${BACKUP_DIR}/`dirname $file`
        chmod +w $file
    fi
done

echo '+ Installing new/updated files...'
cd $NE_BASE
gtar -xvzf ${SourceDir}/${MODULE}-${RP}.tgz
cd $NE_BASE
for file in `gtar -tzf ${SourceDir}/${MODULE}-${RP}.tgz`
do
    if [ -f $file ]
    then
        chmod -w $file
    fi
done

echo '+ Reloading jloader metadata...'
# Reload jloader metadata to make sure loader supports pkswap tables as well
cd ${PROSPECT_HOME}/RANOS_loader/config
make clean_jloader_vendor
make jloader_vendor

echo '+ Configuring hourly partition maintenance setting...'
# Insert "trafficHourly" subclass.
cd ${PROSPECT_HOME}/scripts
make mk_hourlypart

# Compile hourlypart_maint_pkg.sql package.
cd ${PROSPECT_HOME}/scripts/hourlypart
echo '@hourlypart_maint_pkg.sql' | sqlplus -s $DB_CONNECT

for tablename in `cat erc_hourly_tables.txt`
do
    echo "Converting ${tablename}..."

    result=`sqlplus -s $DB_CONNECT << !
                WHENEVER SQLERROR EXIT 1;
                VAR vReturn          NUMBER;
                VAR vPastPart      CHAR(10);
                VAR vPastPart_02   CHAR(10);
                VAR vFuturePart    CHAR(10);
                VAR vFuturePart_02 CHAR(10);
                SET pagesize 0 feedback OFF ver OFF heading OFF echo OFF SERVEROUTPUT ON
                EXEC erc_hourlypart_maint.convert_partition('${tablename}', :vReturn, :vPastPart, :vPastPart_02, :vFuturePart, :vFuturePart_02);
                PRINT :vReturn :vPastPart :vPastPart_02 :vFuturePart :vFuturePart_02;
                EXIT;
                !`

    if [[ $? = 0 ]]
    then
        set -A vars `echo $result`

        if   [[ ${vars[0]} = 0 ]]
        then
            echo 'Old PAST_PART value   : '${vars[1]}
            echo 'New PAST_PART value   : '${vars[2]}
            echo 'Old FUTURE_PART value : '${vars[3]}
            echo 'New FUTURE_PART value : '${vars[4]}

            echo "\nPartition setting converted successfully.\n"
        elif [[ ${vars[0]} = 1 ]]
        then
            echo '"trafficHourly" subclass not exists! Skipped...'"\n"
        elif [[ ${vars[0]} = 2 ]]
        then
            echo '"'$tablename'" table not exists! Skipped...'"\n"
        elif [[ ${vars[0]} = 3 ]]
        then
            echo '"'$tablename'" is already converted! Skipped...'"\n"
        elif [[ ${vars[0]} = 4 ]]
        then
            echo '"'$tablename'" is not supported! Skipped...'"\n"
        fi
    else
        echo "$result\n"
    fi
done

# Update techpart_maint_pkg.sql package to delete and
# insert traffic tables with period set to 'D' only.
cd ${PROSPECT_HOME}/scripts/techpart
echo '@techpart_maint_pkg.sql' | sqlplus -s $DB_CONNECT

echo '+ Installation complete for ProspectBase...'
