#!/bin/ksh
#> This script will upgrade ErcRANOS 6.0.14.0.20
#

########################################################
# set paths and files

RELEASE='6.0.14.0.20'
RP=`echo $RELEASE|sed 's/\.//g'`
MODULE='ErcRANOS'
SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
BACKUP_DIR=${SourceDir}/Backup
export SQLPATH=${FLEXPM_HOME}/config
export wm_product='PROSPECT'
export WM_PRODUCT='PROSPECT'

########################################################


# Check env settings
echo '+ Checking environment...'

if ! [[ -d ${NE_BASE} ]]
then
    echo 'Env variable NE_BASE must be set to appropriate dir before installation.';exit 1
fi

if ! [[ -d ${FLEXPM_HOME} ]]
then
    echo 'Env variable FLEXPM_HOME must be set to appropriate dir before installation.';exit 1
fi

if ! [[ -d ${PROSPECT_HOME} ]]
then
    echo 'Env variable PROSPECT_HOME must be set to appropriate dir before installation.';exit 1
fi

if [[ -z ${DB_CONNECT} ]]
then
    echo 'Env variable DB_CONNECT must be set to appropriate value before installation.';exit 1
fi

if [[ -z ${ORACLE_VERS} ]]
then
    echo 'Env variable ORACLE_VERS must be set to appropriate value before installation.';exit 1
fi

if [[ ${ORACLE_VERS} != 1020 ]]
then
    echo 'This release supports only Oracle 10.2.0.';exit 1
fi

echo '+ Installing Patch...'

echo '+ Backing up original files...'
cd $NE_BASE
for file in `gtar -tzf ${SourceDir}/${MODULE}-${RP}.tgz`
do
    if [ -f $file ]
    then
        if [ ! -d ${BACKUP_DIR}/`dirname $file` ]
        then
            mkdir -p ${BACKUP_DIR}/`dirname $file`
        fi

        cp $file ${BACKUP_DIR}/`dirname $file`
        chmod +w $file
    fi
done

echo '+ Installing new/updated files...'
cd $NE_BASE
gtar -xvzf ${SourceDir}/${MODULE}-${RP}.tgz
cd $NE_BASE
for file in `gtar -tzf ${SourceDir}/${MODULE}-${RP}.tgz`
do
    if [ -f $file ]
    then
        chmod -w $file
    fi
done

# APAR=IZ38565, changing stringToInt(LocalId) to stringToInt(Id)/stringToInt("0")
echo '+ [APAR=IZ38565] Updating wmq_query_text & wmn_entity records...'

# Compile the procedures first
cd ${SourceDir}/scripts
echo '@updateQueryText.sql' | sqlplus -s $DB_CONNECT
echo '@updateEntity.sql'    | sqlplus -s $DB_CONNECT

chk=0

# Update wmq_query_text records for
# SS7Association, HLRSubs, MSCTrunkDest, CnOperator, IuLink entities
for entity in 'SS7Association' 'HLRSubs' 'MSCTrunkDest' 'CnOperator' 'IuLink' 'IuLink'
do
    from_type='LocalId'
      to_type='Id'

    if   [[ $entity = 'SS7Association' ]]
    then
        to_type='"0"'
    elif [[ $entity =         'IuLink' ]]
    then
        if [[ $chk = 0 ]]
        then
            from_type='"0"'
            chk=1
        fi
    fi

    result=`sqlplus -s $DB_CONNECT << !
        WHENEVER SQLERROR EXIT 1;
        VAR vReturn NUMBER;
        SET pagesize 0 feedback OFF ver OFF heading OFF echo OFF SERVEROUTPUT ON
        EXEC updateQueryText('${entity}', '${from_type}', '${to_type}', :vReturn);
        PRINT :vReturn;
        EXIT;
        !`

    if [[ $? = 0 ]]
    then
        if   [[ `echo $result` = 0 ]]
        then
            echo "$entity entity's record in wmq_query_text updated successfully.\n"
        elif [[ `echo $result` = 1 ]]
        then
            echo "WARNING : $entity entity not found!\n"
        fi
    else
        echo "$result\n";exit 1
    fi
done

# Update wmn_entity records for
# SS7Association, HLRSubs, MSCTrunkDest, CnOperator, IuLink entities
for entity in 'SS7Association' 'HLRSubs' 'MSCTrunkDest' 'CnOperator' 'IuLink'
do
    param='Id'

    if   [[ $entity = 'SS7Association' ]]
    then
        param='"0"'
    fi

    result=`sqlplus -s $DB_CONNECT << !
        WHENEVER SQLERROR EXIT 1;
        VAR vReturn NUMBER;
        SET pagesize 0 feedback OFF ver OFF heading OFF echo OFF SERVEROUTPUT ON
        EXEC updateEntity('${entity}', '${param}', :vReturn);
        PRINT :vReturn;
        EXIT;
        !`

    if [[ $? = 0 ]]
    then
        if   [[ `echo $result` = 0 ]]
        then
            echo "$entity entity's record in wmn_entity updated successfully.\n"
        elif [[ `echo $result` = 1 ]]
        then
            echo "WARNING : $entity entity not found!\n"
        fi
    else
        echo "$result\n";exit 1
    fi
done

# Drop the procedure as it is not needed anymore
echo 'DROP PROCEDURE updateQueryText;' | sqlplus -s $DB_CONNECT
echo 'DROP PROCEDURE updateEntity;'    | sqlplus -s $DB_CONNECT

# APAR=IZ29282, APAR=IZ36894, improve loading time of cm_replicate
echo '+ [APAR=IZ29282 & APAR=IZ36894] Compiling new cm_replicate package...'

cd ${PROSPECT_HOME}/RANOS_loader/RANOS_CM/config
echo '@create_replication_pkg.sql'  | sqlplus -s $DB_CONNECT
echo '@create_replication_pkgb.sql' | sqlplus -s $DB_CONNECT

chmod 644 ${PROSPECT_HOME}/RANOS_loader/RANOS_CM/data/LoadAction.txt

# APAR=IZ39809, fix issue on missing entry in ad_scan_tables
echo '+ [APAR=IZ39809] Adding ERC_TF_UTRAN_LOAD_R_TAB to ad_scan_tables...'

cd ${FLEXPM_HOME}/pm/adm

AD_scan_tab_maint.sh -a ERC_TF_UTRAN_LOAD_R_TAB

# to copy AdminGuide.uue from HF1 over
cp ${SourceDir}/uue/AdminGuide.uue ${PROSPECT_HOME}/../ProductRelease/HelpFiles

echo '+ 6.0.14.0.20 Installation complete...'
