#!/bin/ksh
#> This script will upgrade ErcRANOS 6.0.14.0.30
#

########################################################
# set paths and files

RELEASE='6.0.14.0.30'
RP=`echo $RELEASE|sed 's/\.//g'`
MODULE='ErcRANOS'
SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
BACKUP_DIR=${SourceDir}/Backup
export SQLPATH=${FLEXPM_HOME}/config
export wm_product='PROSPECT'
export WM_PRODUCT='PROSPECT'

########################################################


# Check env settings
echo '+ Checking environment...'

if ! [[ -d ${NE_BASE} ]]
then
    echo 'Env variable NE_BASE must be set to appropriate dir before installation.';exit 1
fi

if ! [[ -d ${FLEXPM_HOME} ]]
then
    echo 'Env variable FLEXPM_HOME must be set to appropriate dir before installation.';exit 1
fi

if ! [[ -d ${PROSPECT_HOME} ]]
then
    echo 'Env variable PROSPECT_HOME must be set to appropriate dir before installation.';exit 1
fi

if [[ -z ${DB_CONNECT} ]]
then
    echo 'Env variable DB_CONNECT must be set to appropriate value before installation.';exit 1
fi

if [[ -z ${ORACLE_VERS} ]]
then
    echo 'Env variable ORACLE_VERS must be set to appropriate value before installation.';exit 1
fi

echo '+ Installing Patch...'

echo '+ Backing up original files...'
cd $NE_BASE
for file in `gtar -tzf ${SourceDir}/${MODULE}-${RP}.tgz`
do
    if [ -f $file ]
    then
        if [ ! -d ${BACKUP_DIR}/`dirname $file` ]
        then
            mkdir -p ${BACKUP_DIR}/`dirname $file`
        fi

        cp $file ${BACKUP_DIR}/`dirname $file`
        chmod +w $file
    fi
done

echo '+ Installing new/updated files...'
cd $NE_BASE
gtar -xvzf ${SourceDir}/${MODULE}-${RP}.tgz
cd $NE_BASE
for file in `gtar -tzf ${SourceDir}/${MODULE}-${RP}.tgz`
do
    if [ -f $file ]
    then
        chmod -w $file
    fi
done

echo '+ $RELEASE Installation complete...'
