#!/bin/ksh
#

########################################################
# set paths and files

MODULE="ErcGPRS"
RELEASE="7.1.14.2.0"    
RP=$(echo $RELEASE|sed 's/\.//g')

SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
WorkDir=$SourceDir/workdir
TarFile=${SourceDir}/tarball/${MODULE}_${RP}_UI.tgz

### get ts
TS=`cat $SourceDir/Backup/.ts.txt`
BACKUP_DIR=$SourceDir/Backup/$TS

########################################################

# Check env settings
 echo "Checking environment....."

  if ! [[ -d ${FLEXPM_HOME} ]]; then
     echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
     exit;
  fi

  if ! [[ -d ${NE_BASE} ]]; then
     echo "Env variable NE_BASE must be set to appropriate dir before installation."
     exit;
  fi

  if [ -z ${DB_CONNECT} ]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit 1;
  fi

  ###### module variable validation
  if ! [[ -d ${ErcGPRS_HOME} ]]; then
     echo "Env variable ErcGPRS_HOME must be set to appropriate dir before installation."
     exit;
  fi

    #######################################################
    # Installing module...
    #######################################################

    date +"+ Installing Patch $MODULE $RELEASE at %T, %D ..."

    echo "+ Backing up original files and installing new files..."
    cd $NE_BASE
    mkdir -p ${BACKUP_DIR}

    ${WorkDir}/untar.pl $SourceDir $TarFile $NE_BASE $BACKUP_DIR
    ret=$?

    if [ $ret != 0 ]; then
      echo "+++ Error in untar.pl"
      exit 2
    fi

    ###### module installation customerize here...

    touch parser.err
    chmod 777 parser.err

    echo "### running dict_update ###"
    cd $ErcGPRS_HOME/peik
    make dict_update
    ret=$?

    if [ $ret != 0 ]; then
      echo "+++ Error in make dict_update"
      exit 2
    fi

       echo "### completed dict_update ###"

       #recompile all invalid objects (except for views...):
       echo "+ recompiling invalid object(s)..."
       chmod u+x ${WorkDir}/recompile_schema.sh
       ${WorkDir}/recompile_schema.sh

       #and we recompile for invalid views here...
       echo "+ recompiling invalid view(s)..."
       chmod u+x ${WorkDir}/recompile_view.sh
       ${WorkDir}/recompile_view.sh
       echo " recompiled done."

       date +"+ $MODULE $RELEASE upgrade is completed at %T, %D"
       echo ""

