#!/bin/ksh
#

########################################################
# set paths and files

MODULE="ErcRANOS"
RELEASE="7.1.14.2.0"    
RP=$(echo $RELEASE|sed 's/\.//g')

SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
WorkDir=$SourceDir/workdir
TarFile=${SourceDir}/tarball/${MODULE}_${RP}_UI.tgz

### get ts
TS=`cat $SourceDir/Backup/.ts.txt`
BACKUP_DIR=$SourceDir/Backup/$TS

########################################################

# Check env settings
 echo "Checking environment....."

  if ! [[ -d ${FLEXPM_HOME} ]]; then
     echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
     exit;
  fi

  if ! [[ -d ${NE_BASE} ]]; then
     echo "Env variable NE_BASE must be set to appropriate dir before installation."
     exit;
  fi

  if [ -z ${DB_CONNECT} ]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit 1;
  fi

  ###### module variable validation
  if ! [[ -d ${ErcRANOS_HOME} ]]; then
     echo "Env variable ErcRANOS_HOME must be set to appropriate dir before installation."
     exit;
  fi

    #######################################################
    # Installing module...
    #######################################################

    date +"+ Installing Patch $MODULE $RELEASE at %T, %D ..."

    echo "+ Backing up original files and installing new files..."
    cd $NE_BASE
    mkdir -p ${BACKUP_DIR}

    ${WorkDir}/untar.pl $SourceDir $TarFile $NE_BASE $BACKUP_DIR
    ret=$?

    if [ $ret != 0 ]; then
      echo "+++ Error in untar.pl"
      exit 2
    fi

    echo "+ Performing dict_update for $MODULE module..."
    cd $ErcRANOS_HOME/peik
    make dict_update
    ret=$?

    if [ $ret != 0 ]; then
	echo "+++ dict_update failed for $MODULE module - aborting!"
	exit 2
    fi
    echo "+ $MODULE dict_update completed."

    echo "+ Adding unique constraint to TMP_ERC_UTRANCM_TOPOLOGY table..."
    echo "@${WorkDir}/add_tmp_topology_constraint.sql" | sqlplus ${DB_CONNECT}
    ret=$?

    if [ $ret != 0 ]; then
	echo "+++ Failed to add unique constraint - aborting!"
    fi
    echo "+ Constraint added."

    date +"+ $MODULE $RELEASE upgrade is completed at %T, %D"
    echo ""

